Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(249)

Unified Diff: public/fpdf_formfill.h

Issue 1234053003: Plumb in an externally created v8::Isolate (Closed) Base URL: https://pdfium.googlesource.com/pdfium.git@master
Patch Set: updates Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: public/fpdf_formfill.h
diff --git a/public/fpdf_formfill.h b/public/fpdf_formfill.h
index a1b9ec2a775e03b25659c2c45a262c65c39578f6..f90dd6a6e8ab0b8dd1688672550ff2c5afd40b08 100644
--- a/public/fpdf_formfill.h
+++ b/public/fpdf_formfill.h
@@ -19,7 +19,8 @@ extern "C" {
typedef struct _IPDF_JsPlatform
{
/**
* Version number of the interface. Currently must be 1.
Tom Sepez 2015/07/14 19:34:17 nit: stray line.
**/
int version;
Tom Sepez 2015/07/14 19:32:35 nit: still would like a /* Version 1. */ comment h
@@ -222,6 +223,11 @@ typedef struct _IPDF_JsPlatform
* pointer to FPDF_FORMFILLINFO interface.
**/
void* m_pFormfillinfo;
+
Tom Sepez 2015/07/14 19:32:35 nit: still would like a /* Version 2. */ comment h
+ /**
+ * pointer to the v8::Isolate to use, or NULL to force PDFium to create one.
+ **/
+ void* m_isolate;
} IPDF_JSPLATFORM;
// Flags for Cursor type
@@ -19,7 +19,8 @@ extern "C" {
{
/**
-* Version number of the interface. Currently must be 1.
+* Version number of the interface. Currently must be 2.
+* m_isolate must be set).
Tom Sepez 2015/07/14 19:34:17 nit: stray line.
**/

Powered by Google App Engine
This is Rietveld 408576698